# Course Template Internationalization

[![pypi-image]][pypi-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![license-image]][license-url]
[![codecov][codecov-image]][codecov-url]
[![jupyter-book-image]][docs-url]

<!-- Links: -->
[codecov-image]: https://codecov.io/gh/entelecheia/course-template-i18n/branch/main/graph/badge.svg?token=usYkLC6aBx
[codecov-url]: https://codecov.io/gh/entelecheia/course-template-i18n
[pypi-image]: https://img.shields.io/pypi/v/course-template-i18n
[license-image]: https://img.shields.io/github/license/entelecheia/course-template-i18n
[license-url]: https://github.com/entelecheia/course-template-i18n/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/course-template-i18n?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/course-template-i18n
[release-url]: https://github.com/entelecheia/course-template-i18n/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/entelecheia/course-template-i18n
[pypi-url]: https://pypi.org/project/course-template-i18n
[docs-url]: https://entelecheia.github.io/course-template-i18n
[changelog]: https://github.com/entelecheia/course-template-i18n/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/course-template-i18n/blob/main/CONTRIBUTING.md
<!-- Links: -->

Multilingual course creation template with interactive documentation support for international audiences

- Documentation: [https://entelecheia.github.io/course-template-i18n][docs-url]
- GitHub: [https://github.com/entelecheia/course-template-i18n][repo-url]
- PyPI: [https://pypi.org/project/course-template-i18n][pypi-url]

This project provides a comprehensive and flexible template for creating and managing multilingual online courses. It leverages GitHub for version control and Jupyter Book for interactive content delivery, enabling educators to easily develop, maintain, and share their educational materials across different languages and cultures.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [CC-BY-4.0 License][license-url].
